@@ -45,10 +45,33 @@ DEFUN_DLD (dicomread, args, nargout,
 @deftypefnx {Loadable Function} @var{image} = dicomread (@var{structure}) \n\
 \n\
 Load the image from a DICOM file. \n\
-@var{filename} is a string (giving the filename).\n\
-@var{structure} is a structure with a field @code{Filename} (such as returned by @code{dicominfo}).\n\
-@var{image} may be two or three dimensional, depending on the content of the file. \n\
-An integer or float matrix will be returned, the number of bits will depend on the file. \n\
+@subsubheading Inputs\n\
+@var{filename} - a string giving the filename.*\n\
+\n\
+@var{structure} - a structure with a field @code{Filename} (such as returned by @code{dicominfo}).\n\
+\n\
+@var{image} - may be two or three dimensional, depending on the content of the file. \n\
+\n\
+@subsubheading Outputs\n\
+@var{image} - An integer or float matrix will be returned, the number of bits will depend on the file. \n\
+\n\
+@subsubheading Examples\n\
+Load the image data of a dcm file:\n\
+\n\
+@example\n\
+> image = dicomread(file_in_load_path('imdata/simple-test.dcm'))\n\
+image =\n\
+  0  0  0  0  0\n\
+  0  0  0  0  0\n\
+  0  0  0  0  0\n\
+  0  0  0  0  0\n\
+  0  0  0  0  0\n\
+  0  0  0  0  0\n\
+  0  0  0  0  0\n\
+  0  0  0  0  0\n\
+  0  0  0  0  0\n\
+  0  0  0  0  0\n\
+@end example\n\
 \n\
 @seealso{dicominfo} \n\
 @end deftypefn \n\
@@ -190,9 +213,7 @@ An integer or float matrix will be returned, the number of bits will depend on t
 
 /*
 %!shared testfile
-%! testfile = urlwrite ( ...
-%!   'http://sourceforge.net/p/octave/code/11601/tree/trunk/octave-forge/extra/dicom/dcm_examples/RD.15MV.DCM?format=raw', ...
-%!   tempname() );
+%! testfile = file_in_loadpath("imdata/CT-MONO2-16-ankle.dcm");
 
 %!fail ("dicomread");
 %!fail ("dicomread (1)");
@@ -200,15 +221,11 @@ An integer or float matrix will be returned, the number of bits will depend on t
 
 %!test
 %! rd=dicomread(testfile);
-%! assert(rd(100,101,30),uint16(2021));
+%! assert(rd(100,101),int16(128));
 
 %!test
 %! data={};
 %! data.Filename = testfile;
 %! rd=dicomread(data);
-%! assert(rd(100,101,30),uint16(2021));
-
-%! if exist (testfile, 'file')
-%!   delete (testfile);
-%! endif
+%! assert(rd(100,101),int16(128));
 */
