@@ -62,9 +62,27 @@ DEFUN_DLD (dicomwrite, args, nargout,
 \n\
 Write a DICOM format file to @var{filename}.\n\
 \n\
-@var{im} is image data or empty matrix, [], if only metadata save is required\n\
-@var{filename} is filename to write dicom to. if [], then function runs in verbose trial mode.\n\
-@var{info} struct, like that produced by dicominfo\n\
+@subsubheading Inputs\n\
+@var{im} - image data or empty matrix, [], if only metadata save is required\n\
+\n\
+@var{filename} - filename to write dicom to. if [], then function runs in verbose trial mode.\n\
+\n\
+@var{info} - struct, like that produced by dicominfo\n\
+\n\
+@subsubheading Examples\n\
+Create a dicom file using default info, and the supplied data:\n\
+@example\n\
+> wdata = uint8 (10*rand (10,10));\n\
+> dicomwrite (wdata, 'test.dcm');\n\
+@end example\n\
+\n\
+Create a dicom file using data and meta info:\n\
+\n\
+@example\n\
+> wdata = dicomread(file_in_loadpath('imdata/CT-MONO2-16-ankle.dcm');\n\
+> info = dicominfo(file_in_loadpath('imdata/CT-MONO2-16-ankle.dcm');\n\
+> dicomwrite(wdata, info);\n\
+@end example\n\
 \n\
 @seealso{dicomread, dicominfo}\n\
 @end deftypefn \n\
@@ -400,7 +418,8 @@ void value2element (gdcm::DataElement * de, const octave_value * ov, gdcm::Tag *
         { 
           warning (QUOTED(OCT_FN_NAME)": dicomdict gives VR of SQ for %s, octave value is %s", keyword.c_str(), ov->class_name().c_str());
         }
-      octave_stdout << std::endl;
+      if (trial)
+        octave_stdout << std::endl;
       //int nObj = ov->numel();
       octave_map subom = ov->map_value();
       gdcm::SmartPointer<gdcm::SequenceOfItems> sq = new gdcm::SequenceOfItems();
@@ -412,6 +431,10 @@ void value2element (gdcm::DataElement * de, const octave_value * ov, gdcm::Tag *
         {
           return;
         }
+
+      de->SetValue(*sq);
+      //de->SetVLToUndefined();
+
       sequenceDepth--;
     }
   else
@@ -617,9 +640,8 @@ void genMinimalMetaData(gdcm::ImageWriter *w, gdcm::File *file)
 %! rdata = dicomread (testfile1);
 %! assert(wdata, rdata);
 
-%!fail ("dicominfo", "dicominfo: one arg required: dicom filename");
-%!fail ("dicominfo ([])");
-%!fail ("dicominfo ([],1)");
+%!fail ("dicomwrite", "dicomwrite: should have at least 2 arguments");
+%!fail ("dicomwrite ([],1)");
 
 %!test
 %! wdata = uint8 (10*rand (10,10));
